@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11971 2020-03-09 06:39:08Z Lavender $
+# $Id: setup.py 12064 2020-04-10 07:49:46Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,9 +12,10 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-09 15:39:08 +0900 (週一, 09 三月 2020) $
-# $Revision: 11971 $
+# $Date: 2020-04-10 15:49:46 +0800 (週五, 10 四月 2020) $
+# $Revision: 12064 $
 
+import re
 import os
 import sys
 import time
@@ -27,6 +28,7 @@ import hashlib
 import traceback
 import threading
 import pkg_resources
+import platform
 
 try:
     import colorama 
@@ -54,6 +56,10 @@ handler = logging.StreamHandler()
 handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
+
+INTRODUCTION_URL = "https://www.django-cms-themes.com/static/docs"
+SETUP_URL = "https://www.django-cms-themes.com/static/product/assets/setup.py"
+SETUP_VERSION = "1.0.0"
 SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
 CKEDITOR_SETTINGS = \
 '''
@@ -148,6 +154,12 @@ LOG_URL = "https://www.django-cms-themes.com/log/"
 
 def sendLog(data):
     try:
+        data.update({
+            "setup_version": SETUP_VERSION,
+            "platform_system": str(platform.system()),
+            "platform_version": str(platform.version()),
+            "platform_uname": str(platform.uname()),
+        })
         def job():
             requests.post(LOG_URL, data=data)
         
@@ -156,6 +168,45 @@ def sendLog(data):
     except Exception as e:
         # do nothing
         pass
+        
+def compareVersion(version1, version2):
+    version1 = [int(i) for i in version1.split(".")]
+    version2 = [int(i) for i in version2.split(".")]
+    
+    if version1 >= version2:
+        return True
+    else:
+        return False
+        
+def checkVersion():
+    try:
+        response = requests.get(SETUP_URL)
+        data = response.text
+        result = re.findall(r'SETUP_VERSION = "(\d+.\d+.\d+)"', data)
+        if result:
+            version = result[0]
+            
+            if not compareVersion(SETUP_VERSION, version):
+                logger.warning(colored(
+                    ("Your setup.py version is %s, the latest version is %s available. "
+                     "Download the latest version from the URL below:") % (SETUP_VERSION, version), 
+                    "yellow", attrs=['bold'])
+                )
+                logger.warning(colored(
+                    SETUP_URL, 
+                    "white", attrs=['bold'])
+                )
+                logger.warning(colored(
+                    "Or you can download this theme again to make sure use latest setup.py.", 
+                    "yellow", attrs=['bold'])
+                )
+        else:
+            raise ValueError("Can't read version from %s" % SETUP_URL)
+    except Exception as e:
+        sendLog({
+            "level": "ERROR",
+            "error": str(e),
+        })
 
 if not sys.version_info.major == 3:
     logger.warning(
@@ -450,6 +501,8 @@ if __name__ == "__main__":
         args = parser.parse_args()
         cmd = "python setup.py %s" % " ".join(sys.argv[1:])
         
+        checkVersion()
+        
         try:
             if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
                 with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
@@ -540,7 +593,7 @@ if __name__ == "__main__":
             "upc": upc,
             "command": cmd,
         })
-           
+        
         path = args.path
         
         settingsPath = findSettings(path)
@@ -626,7 +679,7 @@ if __name__ == "__main__":
        
         sys.path.append(path)
         os.environ['DJANGO_SETTINGS_MODULE'] = settingModule        
-            
+        
         try:
             import cms
         except Exception as e:
@@ -804,6 +857,15 @@ if __name__ == "__main__":
             "If you encounter \"No such file or directory: "
             "/env/python3/lib/pythonx.x/site-packages/Django-x.x.x.dist-info/METADATA\" "
             "Please execute setup.py again.", "red"))
+        print("")
+        logger.warning(colored(
+            "Get more instructions for using setup.py from the URL below:", 
+            "yellow", attrs=['bold'])
+        )
+        logger.warning(colored(
+            INTRODUCTION_URL, 
+            "white", attrs=['bold'])
+        )
     try:
         import json
         if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
