@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12012 2020-03-25 11:28:44Z Lavender $
+# $Id: cms_plugins.py 12044 2020-04-05 11:36:35Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-03-25 19:28:44 +0800 (週三, 25 三月 2020) $
-# $Revision: 12012 $
+# $Date: 2020-04-05 19:36:35 +0800 (週日, 05 四月 2020) $
+# $Revision: 12044 $
 
 import re
 import requests
@@ -75,7 +75,7 @@ def getAuthorizationMsg():
         location.reload(true);
     }
     $('#authorization').click(function(){
-        var popupWindow = window.open("%s", "popupWindow", "status=1, height=600, width=600, toolbar=0,resizable=0");
+        var popupWindow = window.open("%s", "popupWindow", "status=1, height=600, width=600, toolbar=0, resizable=0");
         popupWindow.window.focus();
     })
 </script>
@@ -219,10 +219,14 @@ class FacebookFanPlugin(CMSPluginBase):
            
             context.update({
                 'fpList': fpList,
+                'crawler': True,
             })
             
             return context
         else:
+            context.update({
+                'crawler': False,
+            })
             fanPageUrl = instance.url
             fanPageId = getFanPageId(accessToken, instance.url)
 
@@ -395,9 +399,13 @@ class FacebookPhotoPlugin(CMSPluginBase):
             photoList = getFanPhoto(instance.url, instance.limit)
             context.update({
                 'photoList': photoList,
+                'crawler': True,
             })
             return context
         else:
+            context.update({
+                'crawler': False,
+            })
             albumId = None
             fanPageId = getFanPageId(accessToken, instance.url)
             if 'album_id=' in instance.url:
